@@ -131,8 +131,12 @@ merge.zoo <- function(..., all = TRUE, fill = NA, suffixes = NULL, retclass = c(
     # all indexes of args corresponding to all=TRUE with the intersection
     # of all indexes
     indexunion <- do.call("c", indexlist[all])
-    if (is.null(indexunion)) indexunion <- do.call("c", indexlist)[0]
-    indexes <- sort.unique(c(indexunion, indexintersect))
+    
+    indexes <-  if (is.null(indexunion)) indexintersect
+      else sort.unique(c(indexunion, indexintersect))
+    # previously, we used to do:
+    # if (is.null(indexunion)) indexunion <- do.call("c", indexlist)[0]
+    # indexes <- sort.unique(c(indexunion, indexintersect))
 
     ## check whether resulting objects still got the same frequency
     freq <- c(frequency(zoo(,indexes)), freq)
